@@ -14,11 +14,10 @@ use Term::Choose     qw( choose );
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
 use App::YTDL::ChooseVideos qw( choose_videos );
-use App::YTDL::DataExtract  qw( prepare_info );
+use App::YTDL::ExtractData  qw( prepare_info );
 use App::YTDL::GetData      qw( get_vimeo_list_info get_download_info get_youtube_list_info );
 
 
-
 sub from_arguments_to_choices {
     my ( $opt, @ids ) = @_;
     my $info = {};
@@ -102,16 +101,19 @@ sub _generic {
 
 sub _youtube_video_id {
     my ( $opt, $webpage_url ) = @_;
-    return if ! $opt->{fast_list_youtube};
+    return if ! $opt->{list_type_youtube};
     return if ! $webpage_url;
     return if   $webpage_url =~ m|http://|;
-    my $regexp_video_url = qr"          # youtube-dl/youtube_dl/extractor/youtube.py    2016.10.11
+    my $playlist_id_re = qr/(?:PL|LL|EC|UU|FL|RD|UL|TL)[0-9A-Za-z-_]{10,}/;
+
+    my $regexp_video_url = qr"           # youtube-dl/youtube_dl/extractor/youtube.py    2018.06.11
         ^
         (
             (?:https?://|//)                                    # http(s):// or protocol-independent URL
             (?:(?:(?:(?:\w+\.)?[yY][oO][uU][tT][uU][bB][eE](?:-nocookie)?\.com/|
             (?:www\.)?deturl\.com/www\.youtube\.com/|
             (?:www\.)?pwnyoutube\.com/|
+            (?:www\.)?hooktube\.com/|
             (?:www\.)?yourepeat\.com/|
             tube\.majestyc\.net/|
             youtube\.googleapis\.com/)                        # the various hostnames, with wildcard subdomains
@@ -134,10 +136,16 @@ sub _youtube_video_id {
             )
         )?                                                       # all until now is optional -> you can pass the naked ID
         ([0-9A-Za-z_-]{11})                                      # here is it! the YouTube video ID
-        (?!.*?\blist=)                                            # combined list/video URLs are handled by the playlist IE
+        (?!.*?\blist=
+            (?:
+                $playlist_id_re|                                  # combined list/video URLs are handled by the playlist IE    #           %(playlist_id)s|
+                WL                                                # WL are handled by the watch later IE
+            )
+        )
         (?(1).+)?                                                # if we found the ID, everything can follow
         $
     "x;
+
     return $2 if $webpage_url =~ $regexp_video_url; # $2
     return;
 }
@@ -145,33 +153,35 @@ sub _youtube_video_id {
 
 sub _youtube_playlist_id {
     my ( $opt, $webpage_url ) = @_;
-    return if ! $opt->{fast_list_youtube};
+    return if ! $opt->{list_type_youtube};
     return if ! $webpage_url;
     return if   $webpage_url =~ m|http://|;
-    my $regexp_playlist_url = qr"           # youtube-dl/youtube_dl/extractor/youtube.py    2016.10.11
+    my $playlist_id_re = qr/(?:PL|LL|EC|UU|FL|RD|UL|TL)[0-9A-Za-z-_]{10,}/;
+
+    my $regexp_playlist_url = qr"           # youtube-dl/youtube_dl/extractor/youtube.py    2018.06.11
         (?:
             (?:https?://)?
             (?:\w+\.)?
             (?:
                 youtube\.com/
                 (?:
-                    (?:course|view_play_list|my_playlists|artist|playlist|watch|embed/videoseries)
+                    (?:course|view_play_list|my_playlists|artist|playlist|watch|embed/(?:videoseries|[0-9A-Za-z_-]{11}))
                     \? (?:.*?[&;])*? (?:p|a|list)=
                 |  p/
                 )|
                 youtu\.be/[0-9A-Za-z_-]{11}\?.*?\blist=
             )
             (
-                (?:PL|LL|EC|UU|FL|RD|UL)?[0-9A-Za-z-_]{10,}
+                (?:PL|LL|EC|UU|FL|RD|UL|TL)?[0-9A-Za-z-_]{10,}
                 # Top tracks, they can also include dots
                 |(?:MC)[\w\.]*
             )
             .*
             |
-            ((?:PL|LL|EC|UU|FL|RD|UL)[0-9A-Za-z-_]{10,})
+            ($playlist_id_re) #%(playlist_id)s)
         )
-
     "x;
+
     return $1 if $webpage_url =~ $regexp_playlist_url; # $1
     return;
 }
@@ -179,10 +189,10 @@ sub _youtube_playlist_id {
 
 sub _youtube_channel_id {
     my ( $opt, $webpage_url ) = @_;
-    return if ! $opt->{fast_list_youtube};
+    return if ! $opt->{list_type_youtube};
     return if ! $webpage_url;
     return if   $webpage_url =~ m|http://|;
-    my $regexp_channel_url = qr"            # youtube-dl/youtube_dl/extractor/youtube.py    2016.10.11
+    my $regexp_channel_url = qr"            # youtube-dl/youtube_dl/extractor/youtube.py    2018.06.11
         https?://(?:youtu\.be|(?:\w+\.)?youtube(?:-nocookie)?\.com)/channel/(?P<id>[0-9A-Za-z_-]+)
     "x;
     return $+{id} if $webpage_url =~ $regexp_channel_url; # $+{id}
@@ -192,15 +202,11 @@ sub _youtube_channel_id {
 
 sub _youtube_user_id {
     my ( $opt, $webpage_url ) = @_;
-    return if ! $opt->{fast_list_youtube};
+    return if ! $opt->{list_type_youtube};
     return if ! $webpage_url;
     return if   $webpage_url =~ m|http://|;
-    #my $regexp_user_url = qr"           # youtube-dl/youtube_dl/extractor/youtube.py
-    #    (?:(?:(?:https?://)?(?:\w+\.)?youtube\.com/(?:user/)?(?!(?:attribution_link|watch|results)(?:$|[^a-z_A-Z0-9-])))|ytuser:)(?!feed/)(?P<id>[A-Za-z0-9_-]+)
-    #"x; #
-    #return $+{id} if $webpage_url =~ $regexp_user_url; # $+{id}
-    my $regexp_user_url = qr"           # youtube-dl/youtube_dl/extractor/youtube.py    2016.10.11
-        (?:(?:https?://(?:\w+\.)?youtube\.com/(?:(?P<user>user|c)/)?(?!(?:attribution_link|watch|results)(?:$|[^a-z_A-Z0-9-])))|ytuser:)(?!feed/)(?P<id>[A-Za-z0-9_-]+)
+    my $regexp_user_url = qr"           # youtube-dl/youtube_dl/extractor/youtube.py    2018.06.11
+        (?:(?:https?://(?:\w+\.)?youtube\.com/(?:(?P<user>user|c)/)?(?!(?:attribution_link|watch|results|shared)(?:$|[^a-z_A-Z0-9-])))|ytuser:)(?!feed/)(?P<id>[A-Za-z0-9_-]+)
     "x;
     return $+{user}, $+{id} if $webpage_url =~ $regexp_user_url;
     return;
@@ -209,7 +215,7 @@ sub _youtube_user_id {
 
 sub _vimeo_uploader_id {
     my ( $opt, $webpage_url ) = @_;
-    return    if ! $opt->{fast_list_vimeo};
+    return    if ! $opt->{list_type_vimeo};
     return    if ! $webpage_url;
     return $1 if   $webpage_url =~ m{https?://vimeo\.com/(?![0-9]+(?:$|[?#/]))([^/]+)(?:/videos|[#?]|$)};
     return;
@@ -218,7 +224,7 @@ sub _vimeo_uploader_id {
 
 sub _youtube_list_info {
     my( $opt, $type, $list_id ) = @_;
-    printf "Fetching info data ... \n";
+    say "Fetching info data ... ";
     #my $url = sprintf 'https://www.youtube.com/user/%s/videos?sort=dd&view=0&flow=list', $list_id;
     my $url = sprintf 'https://www.youtube.com/%s/%s/videos', lc $type, $list_id;
     my $ex = 'youtube';
@@ -284,7 +290,7 @@ sub _vimeo_list_info {
             prepare_info( $opt, $tmp_info, $ex, $video_id );
         }
         $videos += @{$a_ref};
-        last if $opt->{small_list_size} && $videos >= 48;
+        last if $opt->{list_type_vimeo} == 2 && $videos >= 48;
         last if ! $next;
         $page_nr++;
     }
