@@ -19,7 +19,7 @@ END { print SHOW_CURSOR }
 
 
 sub _choose_fmt {
-    my ( $opt, $info, $ex, $video_id ) = @_;
+    my ( $opt, $info, $ex, $video_id, $keep_chosen ) = @_;
     my $fmt_to_info = $info->{$ex}{$video_id}{fmt_to_info};
     my ( @choices, @format_ids );
     if ( $ex eq 'youtube' ) {
@@ -39,28 +39,44 @@ sub _choose_fmt {
             push @format_ids, $fmt;
         }
     }
+    my @fmt_str;
     my @pre = ( undef );
-    print "\n";
-    # Choose
-    my @idx = choose(
-        [ @pre, @choices ],
-        { prompt => 'Your choice: ', index => 1, order => 1, undef => '<<',
-          meta_items => [ 0 .. $#pre ], include_highlighted => 2 }
-    );
-    return if ! $idx[0];
-    my @fmt_res_idx = map { $_ - @pre } @idx;
-    return @format_ids[@fmt_res_idx];
+    while ( 1 ) {
+        # Choose
+        my $idx = choose(
+            [ @pre, @choices ],
+            { prompt => 'fmt: ' . join( '', @fmt_str ), index => 1, order => 1, undef => '<<' }
+        );
+        if ( ! $idx ) {
+            return if ! @fmt_str;
+            pop @fmt_str;
+            pop @fmt_str;
+            next;
+        }
+        push @fmt_str, @format_ids[ $idx - @pre ];
+        my $enough = 'OK';
+        my @ops = ( undef, $enough, '+', ',', '/', );
+        my $op = choose( \@ops, { prompt => 'fmt: ' . join( '', @fmt_str ), undef => '<<' } );
+        if ( ! defined $op ) { #
+            pop @fmt_str;
+            next;
+        }
+        if ( $op eq $enough ) {
+            return join '', @fmt_str;
+        }
+        push @fmt_str, $op;
+    }
 }
 
 sub download_youtube {
     my ( $opt, $info ) = @_;
     my $qty;
-    if ( $opt->{quality} =~ /^(\d+) or less$/ ) {
+    if ( $opt->{quality} =~ /^\s*(\d+) or less$/ ) {
         $qty = '<=';
         $qty .= '?' if $opt->{no_height_ok};
         $qty .= $1;
     }
-    elsif ( $opt->{quality} =~ /^(\d+) or better$/ ) {
+    elsif ( $opt->{quality} =~ /^\s*(\d+) or better$/ ) {
         $qty = '>=';
         $qty .= '?' if $opt->{no_height_ok};
         $qty .= $1;
@@ -75,22 +91,44 @@ sub download_youtube {
     }
     print up( 2 ) if $total == 0;
     print HIDE_CURSOR;
-    for my $ex ( sort keys %$info ) {
+
+    EX: for my $ex ( sort keys %$info ) {
         my @sorted_video_ids = sort { $info->{$ex}{$a}{count} <=> $info->{$ex}{$b}{count} } keys %{$info->{$ex}};
-        for my $video_id ( @sorted_video_ids ) {
+        my $ask_each = @sorted_video_ids == 1 ? 0 : 1;
+        my $ask_fmt  = 1;
+        my $choice = '';
+        my $keep = 'YES';
+        my $fmt_str;
+
+        VIDEO: for my $video_id ( @sorted_video_ids ) {
             my @cmd = @{$opt->{youtube_dl}};
             #push @cmd, '--skip-download';
             if ( $qty eq 'manually' ) {
-                my @fmt = _choose_fmt( $opt, $info, $ex, $video_id );
-                if ( ! @fmt || ! defined $fmt[0] ) {
-                    next;
+                if ( $ask_each ) {
+                    my $prompt = 'Keep format choices for all videos?';
+                    $choice = choose( [ 'NO', $keep ], { prompt => $prompt } );
+                    if ( ! defined $choice ) {
+                        print $info->{$ex}{$video_id}{count} . '/' . $total . ' skipped' . "\n";
+                        next VIDEO;
+                    }
+                    $ask_each = 0;
                 }
-                push @cmd, '-f', @fmt;
-                print up( 1 );
+
+                if ( $ask_fmt ) {
+                    $fmt_str = _choose_fmt( $opt, $info, $ex, $video_id, $choice eq $keep );
+                    if ( ! defined $fmt_str ) {
+                        print $info->{$ex}{$video_id}{count} . '/' . $total . ' skipped' . "\n";
+                        next VIDEO;
+                    }
+                    $ask_fmt = 0 if $choice eq $keep;
+                }
+                push @cmd, '-f', $fmt_str;
+            }
+            elsif ( $qty eq 'best' ) { #
+                # no format required, because 'best' is default
             }
             else {
                 push @cmd, '-f', "bestvideo[height$qty]+bestaudio/best[height$qty]";
-                push @cmd, '--prefer-free-formats' if $opt->{prefer_free_formats};
             }
             my $output = $opt->{video_dir};
             $output .= '/%(extractor)s' if $opt->{use_extractor_dir};
