@@ -77,11 +77,11 @@ sub _menus {
             [ 'show_help_text',             "  HELP"              ],
             [ 'show_info',                  "  INFO"              ],
             [ 'group_directory',            "- Directory"         ],
-            [ 'group_list_menu',            "- List Menu"         ],
-            [ 'group_quality',              "- Video Format"      ],
+            [ 'group_quality',              "- Quality"           ],
             [ 'group_download',             "- Download"          ],
             [ 'group_output',               "- Info Output"       ],
             [ 'group_history',              "- History"           ],
+            [ 'group_list_menu',            "- Uploader Videos"   ],
             [ 'group_yt_dl_config_file',    "- yt-dl config file" ],
             [ 'group_avail_extractors',     "- Extractors"        ],
         ],
@@ -93,8 +93,8 @@ sub _menus {
             [ 'use_uploader_dir',  "- Uploader directory"   ],
         ],
         group_quality => [
-            [ 'quality',             "- Video quality"       ],
-            [ 'no_height_ok',        "- No video height"        ],
+            [ 'quality',             "- Resolution"          ],
+            [ 'no_height_ok',        "- No video height"     ],
             [ 'prefer_free_formats', "- Prefer free formats" ],
         ],
         group_download => [
@@ -148,7 +148,7 @@ sub _group_prompt {
     my ( $group ) = @_;
     my $group_prompt = {
         group_directory             => "Directories:",
-        group_quality               => "Video Format:",
+        group_quality               => "Video format:",
         group_download              => "Download:",
         group_history               => "History:",
         group_list_menu             => "Uploader video list:",
@@ -255,8 +255,9 @@ sub set_options {
                 }
             }
             elsif ( $choice eq "video_dir" ) {
-                my $prompt = 'Video directory';
-                _opt_choose_a_directory( $opt, $choice, $prompt );
+                my $info = "Video Directory\nNow: " . $opt->{$choice} // 'current directory';
+                my $name = 'New: ';
+                _opt_choose_a_directory( $opt, $choice, $info, $name );
             }
             elsif ( $choice eq "use_extractor_dir" ) {
                 my $prompt = 'Use extractor directories';
@@ -281,18 +282,18 @@ sub set_options {
                 $opt->{useragent} = '' if $opt->{useragent} eq '""';
             }
             elsif ( $choice eq "quality" ) {
-                my $prompt = 'Video quality';
+                my $prompt = 'Video resolution';
                 my $list = [
-                    '180 or less',
-                    '360 or less',
-                    '720 or less',
+                    ' 180 or less',
+                    ' 360 or less',
+                    ' 720 or less',
                     '1080 or less',
                     '1440 or less',
                     '2160 or less',
                     'manually',
-                    '180 or better',
-                    '360 or better',
-                    '720 or better',
+                    ' 180 or better',
+                    ' 360 or better',
+                    ' 720 or better',
                     '1080 or better',
                     '1440 or better',
                     '2160 or better',
@@ -309,14 +310,16 @@ sub set_options {
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "retries" ) {
-                my $prompt = 'Download retries';
                 my $digits = 3;
-                _opt_number_range( $opt, $choice, $prompt, $digits );
+                my $info = sprintf "Download retries\nNow: %${digits}s", insert_sep( $opt->{$choice} );
+                my $name = 'New: ';
+                _opt_number_range( $opt, $choice, $name, $info, $digits );
             }
             elsif ( $choice eq "timeout" ) {
-                my $prompt = 'Connection timeout (s)';
                 my $digits = 3;
-                _opt_number_range( $opt, $choice, $prompt, $digits );
+                my $info = sprintf "Connection timeout (s)\nNow: %${digits}s", insert_sep( $opt->{$choice} );
+                my $name = 'New: ';
+                _opt_number_range( $opt, $choice, $name, $info, $digits );
             }
             elsif ( $choice eq "no_warnings" ) {
                 my $prompt = 'Disable youtube-dl warnings';
@@ -335,9 +338,10 @@ sub set_options {
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "max_size_history" ) {
-                my $prompt = 'Max size of history';
                 my $digits = 3;
-                _opt_number_range( $opt, $choice, $prompt, $digits );
+                my $info = sprintf "Max size of history\nNow: %${digits}s", insert_sep( $opt->{$choice} );
+                my $name = 'New: ';
+                _opt_number_range( $opt, $choice, $name, $info, $digits );
             }
             elsif ( $choice eq "sort_history_by_timestamp" ) {
                 my $prompt = 'Sort history by';
@@ -365,13 +369,23 @@ sub set_options {
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "max_info_width" ) {
-                my $prompt = 'Max Info width';
                 my $digits = 3;
-                _opt_number_range( $opt, $choice, $prompt, $digits );
+                my $info = sprintf "Max Info width\nNow: %${digits}s", insert_sep( $opt->{$choice} );
+                my $name = 'New: ';
+                _opt_number_range( $opt, $choice, $name, $info, $digits );
             }
             elsif ( $choice eq "yt_dl_config_file" ) {
-                my $prompt = 'File: ';
-                _opt_choose_a_file( $opt, $choice, $prompt );
+                my $info = "Youtube-dl Config File\nNow: ";
+                if ( defined $opt->{$choice} ) {
+                    $info .= $opt->{$choice};
+                }
+                else {
+                    $info .= 'default (';
+                    $info .= $^O eq 'MSWin32' ? "%APPDATA%/youtube-dl/config.txt" : "~/.config/youtube-dl/config";
+                    $info .= ')';
+                }
+                my $name = 'New: ';
+                _opt_choose_a_file( $opt, $choice, $info, $name );
             }
             elsif ( $choice eq "yt_dl_ignore_config" ) {
                 my $prompt = 'Ignore youtube-dl config file';
@@ -400,8 +414,8 @@ sub _opt_settings_menu {
 
 
 sub _opt_choose_a_directory {
-    my( $opt, $choice, $prompt ) = @_;
-    my $new_dir = choose_a_dir( { dir => $opt->{$choice} } );
+    my( $opt, $choice, $info, $name ) = @_;
+    my $new_dir = choose_a_dir( { dir => $opt->{$choice}, name => $name, info => $info } );
     return if ! defined $new_dir;
     if ( $new_dir ne $opt->{$choice} ) {
         if ( ! eval {
@@ -420,8 +434,8 @@ sub _opt_choose_a_directory {
 
 
 sub _opt_choose_a_file {
-    my( $opt, $choice, $prompt ) = @_;
-    my $file = choose_a_file( { name => $prompt } );
+    my( $opt, $choice, $info, $name ) = @_;
+    my $file = choose_a_file( { name => $name, info => $info } );
     return if ! defined $file;
     $opt->{$choice} = $file;
     $opt->{change}++;
@@ -445,11 +459,9 @@ sub _local_readline {
 
 
 sub _opt_number_range {
-    my ( $opt, $section, $prompt, $digits ) = @_;
-    my $current = $opt->{$section};
-    $current = insert_sep( $current );
+    my ( $opt, $section, $name, $info, $digits ) = @_;
     # Choose_a_number
-    my $choice = choose_a_number( $digits, { name => "\"$prompt\"", current => $current } );
+    my $choice = choose_a_number( $digits, { name => $name, info => $info } );
     return if ! defined $choice;
     $opt->{$section} = $choice eq '--' ? undef : $choice;
     $opt->{change}++;
